as_nodeset_rsiena: Function to create a node set

View source: R/sienautils.r

as_nodeset_rsienaR Documentation

Function to create a node set

Description

Creates a Siena node set which can be used as the nodes in a Siena network.
The functions as_nodeset_rsiena and sienaNodeSet are identical. The first name is preferred, the other is kept for backward compatibility.

Usage

as_nodeset_rsiena(n, nodeSetName="Actors", names=NULL)

sienaNodeSet(n, nodeSetName="Actors", names=NULL)

Arguments

n

integer, size of set.

nodeSetName

character string naming the node set.

names

optional character string vector of length n of the names of the nodes.

Details

This function is important for data sets having more than one node set, but not otherwise.

Value

Returns a Siena node set, an integer vector, possibly with names, plus the attributes, class equal to "as_nodeset_rsiena", and nodeSetName equal to the argument nodeSetName.

Author(s)

Ruth Ripley

References

See https://www.stats.ox.ac.uk/~snijders/siena/

See Also

as_dependent_rsiena, make_data_rsiena

Examples

senders <- as_nodeset_rsiena(50, nodeSetName="senders")
receivers <- as_nodeset_rsiena(30, nodeSetName="receivers")
senders.attribute <- as_covariate_rsiena(rep(1:10, each=5), 
                        type="monadic", nodeSet="senders")
receivers.attribute <- as_covariate_rsiena(rep(1:5, each=6), 
                        type="monadic", nodeSet="receivers")
mynet <- as_dependent_rsiena(
      array(c(s501[,1:30], s502[,1:30]), dim=c(50, 30, 2)),
      nodeSet=c("senders", "receivers"))
(mydata <- make_data_rsiena(mynet, senders.attribute, receivers.attribute,
      nodeSets=list(senders, receivers)))

RSiena documentation built on April 20, 2026, 5:07 p.m.