print.sienaTest: Print method for Wald and score tests for RSiena results

View source: R/Sienatest.r

print.sienaTestR Documentation

Print method for Wald and score tests for RSiena results

Description

This method prints Wald-type and score-type tests for results estimated by siena.

Usage

## S3 method for class 'sienaTest'
print(x, ...)

Arguments

x

An object of type sienaTest, produced by test_parameter.

...

Extra arguments (not used at present).

Details

The function test_parameter produces an object of type sienaTest. These can be printed by this method.

Value

An object of type sienaTest.

Author(s)

Tom Snijders

See Also

siena, test_parameter.

Examples

mynet <- as_dependent_rsiena(array(c(s501, s502), dim=c(50, 50, 2)))
mydata <- make_data_rsiena(mynet)
myeff <- make_specification(mydata)
myalgo <- set_algorithm_saom(nsub=1, n3=40, seed=1291)
# nsub=1, n3=40 is used here for having a brief computation, not for practice.
myeff <- set_effect(myeff, list(transTrip, transTies))
myeff <- set_effect(myeff, list(outAct, outPop), fix=TRUE, test=TRUE)
(ans <- siena(mydata, effects=myeff, control_algo=myalgo,
                                            silent=TRUE, batch=TRUE))
mprs <- test_parameter(ans, tested=c(3, 4))
print(mprs)

RSiena documentation built on April 20, 2026, 5:07 p.m.