print01Report: Function to produce a basic descriptive report of SIENA data...

View source: R/print01Report.r

write_reportR Documentation

Function to produce a basic descriptive report of SIENA data sets

Description

Prints a report of a Siena data object and its default effects.
The functions write_report and print01Report are identical.
The first name is preferred, the other is kept for backward compatibility.

Usage

## S3 method for class 'sienadata'
write_report(x, outputName=NULL, ...)

print01Report(data, modelname="Siena", getDocumentation=FALSE)

Arguments

x

a Siena data object of class sienadata

data

a Siena data object of class sienadata

outputName

If outputName = NULL and the Siena data set has name dataName, output will be written by write_report to a file with name "dataName_report.txt" in the working directory.
If outputName is not NULL, it should be a character string without embedded spaces, and output will be written to a file with name "outputName_report.txt".

modelname

Character string used to name the output file "modelname.txt"

getDocumentation

Flag to allow documentation of internal functions, not for use by users.

...

Additional arguments, not used now.

Details

First deletes any file of the given name, then writes a new one.

Value

No value returned.

Author(s)

Ruth Ripley, Tom Snijders

References

See https://www.stats.ox.ac.uk/~snijders/siena/

Examples

mynet1 <- as_dependent_rsiena(
             array(c(s501, s502, s503), dim=c(50, 50, 3)))
mydata <- make_data_rsiena(mynet1)
write_report(mydata, outputName=tempfile())

RSiena documentation built on April 20, 2026, 5:07 p.m.