Gui to allow entry of the data for a siena model fit.
siena01Gui(getDocumentation=FALSE)Flag to allow documentation of internal functions, not for use by users.
None, although various objects made will still be in the directory if you are using this within an R session.
This function provides a graphical user interface for fitting Siena
models.
Note that this is less flexible and has fewer possibilities than
creating data objects from matrices and
vectors using sienaDependent, coCovar etc.,
and finally sienaDataCreate.
It can be run from within an R session, but is also called
directly by sienascript (Linux or Mac) (the Windows
interface via siena.exe has now been removed). It allows
entry of details of the data files required, either using the gui or
by loading a session file. The Apply button causes a call to
sienaDataCreateFromSession followed by a display of the
sienaModelOptions screen.
The required format for the column entries is described on the help
page for
sienaDataCreateFromSession, as this function can also be
called directly.
The entries for the table can be loaded from a file by using the
buttons Load new session from file or Continue session
from file. The former will create a new report file and produce a
descriptive report. The latter will use an existing report
file and omit the descriptive report.
Alternatively, use Add and Remove buttons to enter the
file names, and adjust the other columns to describe your data (see
help page for sienaDataCreateFromSession).
The Save to file button will save the entries in the table to a
session file.
The Clear button will empty the table.
The Apply button will prompt to save the session, then create
the data objects and display the sienaModelOptions
screen.
Exit by using the menu File/Quit or by closing the Window.