sienaFit: Methods for processing sienaFit objects, produced by 'siena'

sienaFit.methodsR Documentation

Methods for processing sienaFit objects, produced by siena

Description

print, summary, and xtable methods for sienaFit objects.

Usage

## S3 method for class 'sienaFit'
print(x, tstat=TRUE, ...)

## S3 method for class 'sienaFit'
summary(object, ...)

## S3 method for class 'summary.sienaFit'
print(x, matrices=TRUE, ...)

## S3 method for class 'sienaFit'
coef(object, dropRates=TRUE, shortenNames=TRUE, ...)

## S3 method for class 'sienaFit'
vcov(object, dropRates=TRUE, shortenNames=TRUE, ...)

## S3 method for class 'sienaFit'
write_result(x, type="tex",
    fileName=NULL,
    vertLine=TRUE, tstatPrint=FALSE, sig=FALSE, d=3, ...)

## S3 method for class 'sienaFit'
xtable(x, caption = NULL, label = NULL, align = NULL,
    digits = NULL, display = NULL, ...)

siena_table(x, type="tex",
    fileName=NULL,
    vertLine=TRUE, tstatPrint=FALSE, sig=FALSE, d=3, nfirst=NULL)

Arguments

x

An object of class sienaFit, or summary.sienaFit as appropriate. For siena_table, objects of class sienaBayes are also permitted.

object

An object of class sienaFit, produced by siena. For siena_table, objects of class sienaBayes are also permitted.

dropRates

Logical. Should the results for the basic rate parameters also be given?

shortenNames

Logical. Should the effect names be shortened?

matrices

Boolean: whether also to print in the summary the covariance matrix of the estimates, the derivative matrix of expected statistics X by parameters, and the covariance matrix of the statistics.

tstat

Boolean: if this is NULL, the t-statistics for convergence will not be added to the report.

type

Type of output to produce; must be either "tex" or "html".

fileName

Name of the file; defaults to the name of the sienaFit object. "" indicates output to the console.

vertLine

Boolean: add vertical lines separating the columns in siena_table.

tstatPrint

Boolean: add a column of significance t values (parameter estimate/standard error estimate) to siena_table.

sig

Boolean: adds symbols (daggers and asterisks) indicating significance levels for the parameter estimates to siena_table.

d

The number of decimals places used in siena_table.

caption

See documentation for xtable.

label

See documentation for xtable.

align

See documentation for xtable.

digits

See documentation for xtable.

display

See documentation for xtable

nfirst

Only relevant for the multiSiena package.

...

Add extra parameters for print.xtable here. e.g. type, file.

Value

Function coef.sienaFit gives the estimated parameters, and vcov.sienaFit their estimated variance-covariance matrix.

The function print.sienaFit prints a table containing estimated parameter values, standard errors and (optionally) t-statistics for convergence.

The function summary.sienaFit prints a table containing estimated parameter values, standard errors and t-statistics for convergence together with the covariance matrix of the estimates, the derivative matrix of expected statistics X by parameters, and the covariance matrix of the expected statistics X.

The function xtable.sienaFit creates an object of class xtable.sienaFit which inherits from class xtable and passes an extra arguments to the print.xtable.

The function siena_table outputs a latex or html table of the estimates and standards errors of a sienaFit object. The table will be written to a file in the current directory and has a footnote reporting the maximum of the convergence t-ratios. Endowment or creation effects will be denoted, respectively, by 'maintenance' or 'creation'.

See the manual for how to import the html tables easily into MS-Word.

Author(s)

Ruth Ripley, Charlotte Greenan, Tom Snijders

References

See https://www.stats.ox.ac.uk/~snijders/siena/

See Also

xtable, print.xtable, siena

Examples

myalgorithm <- set_algorithm_saom(nsub=2, n3=100)
mynet <-  as_dependent_rsiena(array(c(tmp3, tmp4), dim=c(32, 32, 2)))
mydata <- make_data_rsiena(mynet)
myeff <- make_specification(mydata)
myeff <- set_effect(myeff, outAct)
ans <- siena(mydata, effects=myeff,
                     control_algo=myalgorithm, batch=TRUE)
ans
coef(ans)
round(vcov(ans), 4)
round(sqrt(diag(vcov(ans))), 4)
summary(ans)
## Not run: 
xtable(ans, type="html", file="ans.html")
write_result(ans, type="html", tstat=TRUE, d=2)

## End(Not run)

RSiena documentation built on April 20, 2026, 5:07 p.m.