Learn R Programming

RSiena (version 1.0.12.141)

sienaNet: Function to create a Siena network object

Description

Creates a Siena network object from a matrix or array or list of sparse matrix of triples.

Usage

sienaNet(netarray, type=c("oneMode", "bipartite", "behavior"),
nodeSet="Actors", sparse=is.list(netarray))

Arguments

Value

An object of class "sienaNet". An array or (networks only) a list of sparse matrices with attributes:netdimsDimensions of the network or behavior variable. Senders, receivers (1 for behavior), periodstypeoneMode, bipartite or behaviorsparseBoolean: whether a list of sparse matrices or notnodeSetCharacter string with name(s) of node set(s)

Details

Adds attributes so that the array or list of matrices can be used in a Siena model fit.

References

See http://www.stats.ox.ac.uk/siena/

See Also

sienaDataCreate

Examples

Run this code
mynet1 <- sienaNet(array(c(s501, s502, s503), dim=c(50, 50, 3)))
mynet2 <- sienaNet(s50a, type="behavior")
mynet3 <- sienaNet(array(c(s501, s502, s503), dim=c(50, 50, 3)),
type="bipartite", nodeSet=c("senders", "receivers"))

Run the code above in your browser using DataLab