Learn R Programming

RSiena (version 1.3.14.3)

RSiena-package: Simulation Investigation for Empirical Network Analysis

Description

Fits statistical models to longitudinal sets of networks, and to longitudinal sets of networks and behavioral variables. Not only one-mode networks but also two-mode networks and multivariate networks are allowed. The models are stochastic actor-oriented models, described in Snijders (2017).

Recent versions of the package are distributed through GitHub, see https://github.com/snlab-nl/rsiena/ .

Arguments

Author

Ruth Ripley, Krists Boitmanis, Tom Snijders, Felix Schoenenberger, Nynke Niezink. Contributions by Josh Lospinoso, Charlotte Greenan, Viviana Amati, Christian Steglich, Johan Koskinen, Mark Ortmann, Natalie Indlekofer, Christoph Stadtfeld, Per Block, Marion Hoffman, Michael Schweinberger, Robert Hellpap, Alvaro Uzaheta, and Steffen Triebel.

Maintainer: Tom A.B. Snijders <tom.snijders@nuffield.ox.ac.uk>

Details

The main flow of operations of this package is as follows.

Data objects can be created from matrices and vectors using sienaDependent, coCovar, varCovar, coDyadCovar, etc., and finally sienaDataCreate.

Effects are selected using an sienaEffects object, which can be created using getEffects and may be further specified by includeEffects, setEffect, and includeInteraction.

Control of the estimation algorithm requires a sienaAlgorithm object that defines the settings (parameters) of the algorithm, and which can be created by sienaAlgorithmCreate.

Function siena07 is used to fit a model. Function sienaGOF can be used for studying goodness of fit.

A general introduction to the method is available in the tutorial paper Snijders, van de Bunt, and Steglich (2010). Next to the help pages, more detailed help is available in the manual (see below) and a lot of information is at the website (also see below).

Package:RSiena
Type:Package
Version:1.3.13
Date:2022-10-07
Depends:R (>= 3.5.0)
Imports:Matrix, lattice, parallel, MASS, methods, xtable
Suggests:network, tools, codetools, tcltk
SystemRequirements:GNU make
License:GPL-2 | GPL-3
LazyData:yes
NeedsCompilation:yes
BuildResaveData:no

References

  • Amati, Viviana, Schoenenberger, Felix, and Snijders, Tom A.B. (2019). Contemporaneous statistics for estimation in stochastic actor-oriented co-evolution models. Psychometrika 84, 1068--1096.

  • Schweinberger, Michael, and Snijders, Tom A.B. (2007). Markov models for digraph panel data: Monte Carlo-based derivative estimation. Computational Statistics and Data Analysis 51, 4465--4483.

  • Snijders, Tom A.B. (2001). The statistical evaluation of social network dynamics. Sociological Methodology 31, 361-395.

  • Snijders, Tom A.B. (2017). Stochastic Actor-Oriented Models for Network Dynamics. Annual Review of Statistics and Its Application 4, 343--363.

  • Snijders, Tom A.B., van de Bunt, Gerhard G., and Steglich, Christian E.G. (2010). Introduction to actor-based models for network dynamics. Social Networks 32, 44--60.

  • Snijders, Tom A.B., Steglich, Christian E.G., and Schweinberger, Michael (2007). Modeling the co-evolution of networks and behavior. Pp. 41--71 in Longitudinal models in the behavioral and related sciences, edited by Kees van Montfort, Han Oud and Albert Satorra; Lawrence Erlbaum.

  • Steglich, Christian E.G., Snijders, Tom A.B., and Pearson, Michael A. (2010). Dynamic networks and behavior: Separating selection from influence. Sociological Methodology 40, 329--393.

  • The manual: http://www.stats.ox.ac.uk/~snijders/siena/RSiena_Manual.pdf

  • The website: http://www.stats.ox.ac.uk/~snijders/siena/.

See Also

siena07

Examples

Run this code
mynet1 <- sienaDependent(array(c(tmp3, tmp4), dim=c(32, 32, 2)))
mydata <- sienaDataCreate(mynet1)
myeff <- getEffects(mydata)
myeff <- includeEffects(myeff, transTrip)
myeff
myalgorithm <- sienaAlgorithmCreate(nsub=3, n3=200)
ans <- siena07(myalgorithm, data=mydata, effects=myeff, batch=TRUE)
summary(ans)

Run the code above in your browser using DataLab