Learn R Programming

RSiena (version 1.0.11.110)

print.sienaMeta: Methods for processing sienaMeta objects

Description

print, summary, and plot methods for sienaMeta objects.

Usage

## S3 method for class 'sienaMeta':
print(x, file=FALSE, ...)

## S3 method for class 'sienaMeta': summary(object, file=FALSE, extra=TRUE, ...)

## S3 method for class 'summary.sienaMeta': print(x, file=FALSE, extra=TRUE, ...)

## S3 method for class 'sienaMeta': plot(x, ...)

Arguments

Value

The function print.sienaMeta prints details of the merged estimates of the meta-analysis, with test statistics.

The function summary.sienaMeta prints details as for the print method, but also details of the sienaFit objects included.

Output from either can be directed to a file by using the argument file. It will be appended to any existing file of the same name: projname.out where projname is the value of the argument to siena08.

The function plot.sienaMeta plots estimates against standard errors for each effect, with lines added at x=2. T. A. B. Snijders and Chris Baerveldt. Multilevel network study of the effects of delinquent behavior on friendship evolution. Journal of Mathematical Sociology, 27: 123--151, 2003. See also http://www.stats.ox.ac.uk/~snijders/siena/ [object Object]

mymodel <- sienaModelCreate(fn=simstats0c, nsub=2, n3=100) mynet1 <- sienaNet(array(c(s501, s502), dim=c(50, 50, 2))) mynet2 <- sienaNet(array(c(s502, s503), dim=c(50, 50, 2))) mydata1 <- sienaDataCreate(mynet1) mydata2 <- sienaDataCreate(mynet2) myeff1 <- getEffects(mydata1) myeff2 <- getEffects(mydata2) myeff1 <- setEffect(myeff1, transTrip, fix=TRUE, test=TRUE) myeff2 <- setEffect(myeff2, transTrip, fix=TRUE, test=TRUE) myeff1 <- setEffect(myeff1, cycle3, fix=TRUE, test=TRUE) myeff2 <- setEffect(myeff2, cycle3, fix=TRUE, test=TRUE) ans1 <- siena07(mymodel, data=mydata1, effects=myeff1, batch=TRUE) ans2 <- siena07(mymodel, data=mydata2, effects=myeff2, batch=TRUE) meta <- siena08(ans1, ans2) meta summary(meta) plot(meta) methods