print, summary, and plot methods for
sienaMeta objects.## S3 method for class 'sienaMeta':
print(x, file=FALSE, ...)## S3 method for class 'sienaMeta':
summary(object, file=FALSE, extra=TRUE, ...)
## S3 method for class 'summary.sienaMeta':
print(x, file=FALSE, extra=TRUE, ...)
## S3 method for class 'sienaMeta':
plot(x, ...)
print.sienaMeta prints details of the merged
estimates of the meta-analysis, with test statistics. The function summary.sienaMeta prints details as for the
print method, but also details of the sienaFit objects
included.
Output from either can be directed to a file by using the argument
file. It will be appended to any existing file of the same
name: projname.out where projname is the value of the
argument to siena08.
The function plot.sienaMeta plots estimates against standard
errors for each effect, with lines added at