View source: R/print01Report.r
| write_report | R Documentation |
Prints a report of a Siena data object and its default effects.
The functions write_report and print01Report
are identical.
The first name is preferred,
the other is kept for backward compatibility.
## S3 method for class 'sienadata'
write_report(x, outputName=NULL, ...)
print01Report(data, modelname="Siena", getDocumentation=FALSE)
x |
a Siena data object of class |
data |
a Siena data object of class |
outputName |
If |
modelname |
Character string used to name the output file " |
getDocumentation |
Flag to allow documentation of internal functions, not for use by users. |
... |
Additional arguments, not used now. |
First deletes any file of the given name, then writes a new one.
No value returned.
Ruth Ripley, Tom Snijders
See https://www.stats.ox.ac.uk/~snijders/siena/
mynet1 <- as_dependent_rsiena(
array(c(s501, s502, s503), dim=c(50, 50, 3)))
mydata <- make_data_rsiena(mynet1)
write_report(mydata, outputName=tempfile())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.