Learn R Programming

RSiena (version 1.0.11.110)

siena08: Funtion to perform a meta analysis of a collection of Siena fits.

Description

Estimates a meta analysis based on a collection of Siena fits.

Usage

siena08(..., projname = "sienaMeta", bound = 5)

Arguments

Value

An object of class sienaMeta. There are print, summary and plot methods for this class.

An object of class sienaMeta is a list containing at least the following. (Items regfit to ns appear once for each effect.)regfitPart of the result of the fit of iwlsm.regsummaryThe summary of the fit, which includes the coefficient table.Tsqtest statistic for effect zero in every modelpTsqp-value for abovetratiotest statistics that mean effect is 0ptratiop-value for aboveQstatTest statisitc for variance of effects is zeropttildep-value for abovecjplusTest statistic for at least one theta strictly greater than 0cjminusTest statistic for at least one theta strictly less than 0cjpluspp-value for cjpluscjminuspp-value for cjminusn1Number of fits on which the meta analysis is basedscoreplusTest statistic for combination of right one-sided p-values from score testsscoreminusTest statistic for combination of left one-sided p-values from score testsscoreplusppvalue for scoreplusscoreminuspp-value for scoreminusnsNumber of fits on which the score test analysis is basedthetadfData frame containing the coefficients, standard errors and score test resultsprojnameName for any output file to be produced by the print methodboundEstimates with standard error above this value were excluded from the calculations.scoresObject of class by indicating, for each effect in the models, whether score test information was present.

Details

A meta analysis as described in the reference below is performed. This consists of two parts: an iterated weighted least squares and some calculations of Fisher combinations of p-values.

References

T. A. B. Snijders and Chris Baerveldt. Multilevel network study of the effects of delinquent behavior on friendship evolution. Journal of Mathematical Sociology, 27: 123--151, 2003. See also http://www.stats.ox.ac.uk/~snijders/siena/

See Also

sienaMeta, siena07

Examples

Run this code
mymodel <- sienaModelCreate(fn=simstats0c, nsub=2, n3=100)
mynet1 <- sienaNet(array(c(s501, s502), dim=c(50, 50, 2)))
mynet2 <- sienaNet(array(c(s502, s503), dim=c(50, 50, 2)))
mydata1 <- sienaDataCreate(mynet1)
mydata2 <- sienaDataCreate(mynet2)
myeff1 <- getEffects(mydata1)
myeff2 <- getEffects(mydata2)
myeff1 <- setEffect(myeff1, transTrip, fix=TRUE, test=TRUE)
myeff2 <- setEffect(myeff2, transTrip, fix=TRUE, test=TRUE)
myeff1 <- setEffect(myeff1, cycle3, fix=TRUE, test=TRUE)
myeff2 <- setEffect(myeff2, cycle3, fix=TRUE, test=TRUE)
ans1 <- siena07(mymodel, data=mydata1, effects=myeff1, batch=TRUE)
ans2 <- siena07(mymodel, data=mydata2, effects=myeff2, batch=TRUE)
meta <- siena08(ans1, ans2)

Run the code above in your browser using DataLab