Learn R Programming

RSiena (version 1.0.11.110)

sienaNet: Function to create a Siena network object

Description

Creates a Siena network object from a matrix or array or list of sparse matrix of triples.

Usage

sienaNet(netarray, type=c("oneMode", "bipartite", "behavior"),
nodeSet="Actors", sparse=is.list(netarray))

Arguments

Value

An object of class "sienaNet".

Details

Adds attributes so that the array or list of matrices can be used in a Siena model fit.

References

See http://www.stats.ox.ac.uk/siena/

See Also

sienaDataCreate

Examples

Run this code
mynet1 <- sienaNet(array(c(s501, s502, s503), dim=c(50, 50, 3)))

Run the code above in your browser using DataLab