Learn R Programming

RSiena (version 1.0.12.141)

simstats0c: A version of FRAN

Description

The function to be called as 'FRAN' by siena07 in case of estimation by Method of Moments. Calls compiled C++.

Usage

simstats0c(z, x, INIT = FALSE, TERM = FALSE, initC=FALSE,
           data=NULL, effects=NULL, fromFiniteDiff=FALSE,
           profileData=FALSE, prevAns=NULL, returnDeps=FALSE)

Arguments

Value

Depends on the call. If INIT or initC or TERM are true, returns z, the control object. Otherwise, returns a list containing:fraSimulated statistics.scScores with which to calculate the derivative (not phase 2 or if using finite differences or maximum likelihood).dffFor maximum likelihood, 2nd deriv??ntimFor conditional processing, time taken.feasibleCurrently set to TRUE.OKCould be set to FALSE if serious error has occurred.simsA list of simulation results, one for each iteration. Each list consists of a list for each data object, each of which consists of a list for each network, each of which consists of a list for each period, each component of which is an edgelist in matrix form (the columns are from, to, value) (or vector for behavior variables). Only if returnDeps is TRUE.

Details

This should be used for the element FRAN of the model object in case of estimation by Method of Moments. The arguments with no defaults must be passed in on the call to siena07.

References

See http://www.stats.ox.ac.uk/~snijders/siena/

See Also

siena07

Examples

Run this code
mynet1 <- sienaNet(array(c(tmp3, tmp4), dim=c(32, 32, 2)))
mydata <- sienaDataCreate(mynet1)
myeff<- getEffects(mydata)
myeff[myeff$effectName=='transitive triplets'&
            myeff$type=='eval','include']<- TRUE
mymodel<- sienaModelCreate(fn = simstats0c, nsub=2, n3=100)
ans<- siena07(mymodel, data=mydata, effects=myeff,  batch=TRUE)

Run the code above in your browser using DataLab